import click


@click.option("-u", "--pms-user", default=None, type=click.STRING, help="")
@click.option("-p", "--pms-password", default=None, type=click.STRING, help="")
@click.option("-t", "--task-id", default=None, type=click.STRING, help="")
@click.option("-s", "--suite-id", default=None, type=click.STRING, help="")
@click.option("-sp", "--send2pms", default=None, type=click.STRING, help="")
def cli(
        pms_user,
        pms_password,
        task_id,
        suite_id,
        send2pms,
):
    if task_id:
        from pms_driver.task import Task
        Task(pms_user, pms_password).write_case_data(task_id)
    elif suite_id:
        from pms_driver.suite import Suite
        Suite(pms_user, pms_password).write_case_data(suite_id)
    if send2pms:
        from pms_driver.send2pms import Send2Pms
        Send2Pms(pms_user, pms_password, task_id, suite_id).send()


if __name__ == "__main__":
    cli()



import json
import os
import pathlib
import re

import requests

SEND_PMS_RETRY_NUMBER = 2

runs_id_cmd_log = lambda x: re.sub(r"'run_case_id': '\d+', ", "", str(x))


class Send2Pms:
    """发送数据到pms"""

    __author__ = "huangmingqiang@uniontech.com"

    def __init__(self, username, password, task_id=None, suite_id=None):
        self.task_id = task_id
        self.suite_id = suite_id
        self.base_url = "https://pms.uniontech.com"
        loginurl = f'{self.base_url}/zentao/user-login.json'
        datauser = {"account": username, "password": password}
        self.session = requests.Session()
        self.session.post(loginurl, data=datauser)
        self.rootdir = pathlib.Path(".").absolute()
        self.reportdir = self.rootdir / "report"

    def get_run_case_id_map(self):
        with open(self.reportdir / f"pms_{self.task_id}" / "run_case_id_map.json") as f:
            run_case_id_map = json.load(f)
        return run_case_id_map

    def get_task_step_id(self, run_case_id):
        base_url = "https://pms.uniontech.com/testtask-runCase"
        self.run_case_html_url = f"{base_url}-{run_case_id}.html"
        res = self.session.get(self.run_case_html_url).text
        steps_id = re.findall(r"name='steps\[(\d+)\]'", res)
        if steps_id and steps_id[0]:
            return steps_id[0]
        return 201

    def get_suite_step_id(self, run_case_id):
        base_url = "https://pms.uniontech.com/testtask-runCase"
        self.run_case_html_url = f"{base_url}-0-{run_case_id}-1.html"
        res = self.session.get(self.run_case_html_url).json()
        steps_id = re.findall(r"name='steps\[(\d+)\]'", res)
        if steps_id and steps_id[0]:
            return steps_id[0]
        return 201

    def get_json_report(self):
        for filename in os.listdir(self.reportdir / "json"):
            json_file = self.reportdir / "json" / filename
            return json_file

    def send(self):
        json_file = self.get_json_report()
        run_case_id_map = self.get_run_case_id_map()
        with open(json_file, "r", encoding="utf") as f:
            json_data = json.load(f)
        cases_res = json_data.get("tests")
        for case in cases_res:
            case_id = re.findall(r"test_.*?_(\d+)", case.get("nodeid"))[0]
            run_case_id = run_case_id_map.get(case_id)
            if self.task_id:
                steps_id = self.get_task_step_id(run_case_id)
            elif self.suite_id:
                steps_id = self.get_suite_step_id(run_case_id)
            else:
                raise ValueError

            outcome = case.get("outcome")
            if outcome == "passed":
                result = "pass"
            elif outcome == "failed":
                result = "fail"
            else:
                continue
            data = {
                f"steps[{steps_id}]": result,
                f"reals[{steps_id}]": "",
                "case": case_id,
                "version": "1",
                f"labels{steps_id}[]": "",
                f"files{steps_id}[]": "",
            }
            res = self.session.post(url=self.run_case_html_url, data=data)
            print(self.run_case_html_url, res.status_code)




import json
import os

import requests

MAX_CASE_NUMBER = 100000


class Task:
    """获取测试套件关联的用例"""

    __author__ = "huangmingqiang@uniontech.com"

    def __init__(self, username, password):
        self.base_url = "https://pms.uniontech.com"
        loginurl = f'{self.base_url}/zentao/user-login.json'
        datauser = {"account": username, "password": password}
        self.session = requests.Session()
        self.session.post(loginurl, data=datauser)

    def get_task_data(self, task_id):
        task_json_url = f"https://pms.uniontech.com/testtask-cases-{task_id}-all-0-id_desc-4-{MAX_CASE_NUMBER}-1.json"
        try:
            res = self.session.get(task_json_url).json()
            data = json.loads(res.get("data"))
            runs = data.get("runs")
        except json.decoder.JSONDecodeError:
            raise EnvironmentError(
                f"{task_json_url} 未获取到有效数据！\n 请检查你的PMS账号密码是否正确。"
            )
        runs_ids = []
        run_case_id_map = {}
        for run_case_id in runs:
            # 产品库ID
            case_id = runs.get(run_case_id).get("case")
            runs_ids.append(case_id)
            run_case_id_map[case_id] = run_case_id
            # 用例库ID
            from_case_id = runs.get(run_case_id).get("fromCaseID")
            if from_case_id:
                runs_ids.append(from_case_id)
                run_case_id_map[from_case_id] = run_case_id
        return runs_ids, run_case_id_map

    def write_case_data(self, task_id):
        ids, run_case_id_map = self.get_task_data(task_id)
        with open(f'youqu-tags.txt', "w", encoding="utf-8") as f:
            f.write(" or ".join(ids))
        run_case_ids_dir = f"./report/pms_{task_id}"
        if not os.path.exists(run_case_ids_dir):
            os.makedirs(run_case_ids_dir)
        with open(os.path.join(run_case_ids_dir, "run_case_id_map.json"), "w", encoding="utf-8") as f:
            f.write(json.dumps(run_case_id_map, indent=2, ensure_ascii=False))
